.\" Emacs: -*- nroff -*-
.TH wots 1 ""
.SH NAME
\fBwots\fP - jolly nice log watcher program
.SH SYNOPSIS
\fBwots\fP
[--config=FILE]
[--pidfile=FILE]
[--debug[=on|off]]
[--count=N]
[--help]
[--version]
.SH VERSION
This is \fBwots\fP version 1.22.
.SH DESCRIPTION
\fBwots\fP is a configurable logfile watching program.
It monitors a set of logfiles looking for message lines to
match against patterns and actions to perform when a match
occurs.
\fBwots\fP is best described via its options and examples.
The default values are listed in the defaults section.
.SH OPTIONS
.LP
\fBwots\fP uses the GNU extended POSIX option format:
.IP "-config FILE, --config=FILE" 4
The definitions of logfiles, patterns to be matched, and
the associated actions are in FILE.
See configuration section below.
.IP "-pidfile FILE, --pidfile=FILE" 4
\fBwots\fP records its process id in file FILE.
This makes it easy to send signals to \fBwots\fP.
See signals section below.
.IP "-debug, --debug[=on|off]" 4
See DIRECTIVES.
.IP "-count N, --count=N" 4
See DIRECTIVES.
.IP "-help, --help" 4
Give a usage summary and exit.
.IP "-version, --version" 4
Display the current version, and die.
.SH CONFIGURATION
The configuration file for \fBwots\fP lists the logfiles
to be watched, patterns to look for in those logfiles and
what to do if a pattern is found.
.LP
.SH DIRECTIVES
Note: the "config" directives "poll" and "nice" are not
present on the command line; this is because subsequent
reads of the configuration override the initial command line
settings.  So it seemed more sensible to locate them solely
in the configuration file.
.IP "config poll N" 4
Check the logfiles listed in the configuration file every
N seconds.
.IP "config count N" 4
Check the logfiles N times.
A count of 1 makes \fBwots\fP scan all the logfiles once
all the way through and exit, otherwise \fBwots\fP behaves
like "tail -f".
.IP "config nice PRIO" 4
Renice this process to priority PRIO.
.IP "config debug on|off" 4
Show (lots of) internal information about what \fBwots\fP
is doing.  With no argument, assume "on".
For debugging, or for the hopelessly inquisitive.
.IP "from LOGFILE" 4
starts a pattern/action section for the named LOGFILE.  This
logfile is current until the next "from" or end-of-file.
.IP "from ! PROCESS" 4
.IP "from pipe PROCESS" 4
.IP "from once PROCESS" 4
starts a pattern/action section for the named PROCESS.
Output from the process (stdout) is the input space for
pattern matches.  ``!'' and ``pipe'' are synonyms,
``once'' will run PROCESS on each pass, but any actions
will be executed at most once, until \fBwots\fP does
a re-read of its configuration or is restarted.
.IP "echoformat STRING" 4
.IP "mailformat STRING" 4
STRING is a template which defines how "echo" and "mail" will
format their output when called as actions.
.IP
The default echo format is ~L:~M which is the logfile name,
a colon and the matched pattern.
.IP
The default mail format is ~M.
.IP
The STRING is pre-processed by strftime() so the relevant % escapes will
be handled too.
.IP
Outside of a "from" context, these commands are global, inside
a "from", they apply only to the current logfile.
.IP
NB: these directives are likely to change to a more extensible format.
.SH PATTERNS AND ACTIONS
An action/pattern line has the format
.LP
.RS
/pattern/ <space> action[,action...]
.RE
.LP
All of the patterns in \fBwots\fP are dealt with by perl, so
basically you can use anything that perl would cope with as
a regular expressions.  \fBwots\fP checks all the regular
expressions in the configuration file at start-up so you
don't get bitten by perl croaking over a bad pattern when
something matches it at a later time.  A pattern is, as
usual, delimited by "/".
.LP
There is a selection of actions
.IP "echo[=style[;style...]]" 4
if the pattern matched, then echo the match to standard output,
optionally with the named style, e.g. bold, underline,
reverse, on_blue.  These are taken directly from Term::ANSIColor, q.v.
.IP "mail[=address]" 4
if the pattern matched, then send mail to the supplied address
if given, or to the user who started this \fBwots\fP if not given.
.IP "exec=command" 4
if the pattern matched, then spawn the given command.  The
command may contain $1, $2, etc. which are replaced with
bracketed matches from the pattern.
.IP
The command will be run in the foreground by default, but
putting "&" at the end of the command will run it in the
background (handy for things like xmessage and friends).
.IP "bell" 4
if the pattern matched, ring the bell.
Sanctuary, Esmerelda...
.IP "ignore" 4
if the pattern matched, don't do anything
(handy for catch-all situations).
.SH SIGNALS
\fBwots\fP responds to various signals to let you
control already running instances.
.IP "SIGHUP" 4
makes \fBwots\fP re-read its configuration file and start
scanning all the logfiles again.
.IP "SIGINT" 4
makes \fBwots\fP exit.
.IP "SIGTERM" 4
same as SIGINT.
.SH DEFAULTS
.IP "~/.wotsrc" 4
location of configuration file.
.IP "./wots.pid" 4
location of process-id file.
.IP "poll 5" 4
how often to check logfiles.
.IP "no nice" 4
don't change the priority.
.IP "no debug" 4
debug tracing is turned off.
.IP "no count" 4
loop forever looking at the files.
.SH EXAMPLES
A simple configuration file
.LP
.RS
config poll 30
.br
from /var/log/printers
.br
/out of paper/             mail,echo
.br
/jam/                      bell,echo
.br
from /var/adm/messages
.br
echoformat "~L\en  ~M"
.br
.na
/panic/                    exec=xmessage EEEEK&
.fi
.RE
.SH WHY WOTS?
\fBwots\fP was written to feel as much like swatch as
possible.  I was using swatch to monitor things but thought
it was lacking a few features and \fBwots\fP is the result.
.LP
Although \fBwots\fP owes a lot to the ideas behind swatch,
all of the code is new.
.LP
As for the name \fBwots\fP, I was listening to the Genesis
album "Foxtrot" while writing the code.  One of the songs on
this album is called "Watcher Of The Skies" and contains the
lyrics "watcher of the skies, watcher of all".  So now you
know.
.SH SEE ALSO
swatch(1), perl(1), strftime(3), signal(2), tail(1).
.SH TODO AND BUGS
Extended signal handling, more robust configuration parsing,
time constraints on actions (e.g. echo "panic" messages
during business hours, otherwise mail them when I'm not
there).
.LP
I don't like the ``once'' thing, it needs to be rethought.
.SH AUTHOR
Tony Curtis <Tony.Curtis@vcpc.univie.ac.at>
.LP
Thanks to
.LP
Martin Paul
.br
William Annis
.br
Michael Fischer
.br
Lionel Cons
.LP
for lots of testing, bug reports, and helpful suggestions.
